/* $Id: MUSICDrumDescriptor.cc,v 1.2 2003/08/08 12:05:13 andete Exp $

lemux - LADSPA instrument plugins based on openMSX devices

(c) 2003 Joost Yervante Damad <joost@lumatec.be>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "MUSICDrumDescriptor.hh"
#include "LADSPAPluginInstance.hh"
#include "LADSPAPortDescriptor.hh"
#include "LADSPAPluginDescriptor.hh"
#include "MUSICDrumInstance.hh"

#include <string>
#include <sstream>

MUSICDrumDescriptor::MUSICDrumDescriptor()
:
	LADSPAPluginDescriptor
		(
			2065,
			std::string("MUSICDrum"),
			std::string("MUSIC Drum instruments"),
			std::string("Joost Yervante Damad"),
			std::string("GPLv2")
		)
{
	LADSPAPortDescriptor *port;

	port = new LADSPAPortDescriptor
		(
			std::string("Freq (Hz) BD"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::SampleRate   |
				LADSPAPortDescriptor::Logarithmic  |
				LADSPAPortDescriptor::Default440,

			0,
			0.5
		); addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Freq (Hz) SD,T-CY,HH"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::SampleRate   |
				LADSPAPortDescriptor::Logarithmic  |
				LADSPAPortDescriptor::Default440,

			0,
			0.5
		); addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Freq (Hz) TOM,T-CY,HH"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::SampleRate   |
				LADSPAPortDescriptor::Logarithmic  |
				LADSPAPortDescriptor::Default440,

			0,
			0.5
		); addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Amplitude BD"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			15
		); addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Amplitude SD,T-CY,HH"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			15
		); addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Amplitude TOM,T-CY,HH"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Control ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			15
		); addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Output"),
			
				LADSPAPortDescriptor::Output   |
				LADSPAPortDescriptor::Audio
		);
	addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Gate Bass Drum"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Audio ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			1
		);
	addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Gate Snare Drum"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Audio ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			1
		);
	addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Gate Tom-Tom"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Audio ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			1
		);
	addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Gate Top Cymbal"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Audio ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			1
		);
	addPort(port);

	port = new LADSPAPortDescriptor
		(
			std::string("Gate High-Hat"),
			
				LADSPAPortDescriptor::Input   |
				LADSPAPortDescriptor::Audio ,
			
				LADSPAPortDescriptor::BoundedBelow |
				LADSPAPortDescriptor::BoundedAbove |
				LADSPAPortDescriptor::Default0,

			0,
			1
		);
	addPort(port);
}

MUSICDrumDescriptor::~MUSICDrumDescriptor()
{
}

LADSPAPluginInstance* MUSICDrumDescriptor::create(unsigned long SampleRate)
{
	return new MUSICDrumInstance(SampleRate);
}
