/* $Id: PSGInstance.hh,v 1.2 2003/08/06 10:54:53 andete Exp $

lemux - LADSPA instrument plugins based on openMSX devices

(c) 2003 Joost Yervante Damad <joost@lumatec.be>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifndef   __PSGINSTANCE_HH__
#define   __PSGINSTANCE_HH__

#include <math.h>

#include "LADSPAPluginInstance.hh"

class PSGInstance: public LADSPAPluginInstance
{
public:
	PSGInstance(unsigned long sampleRate);
	virtual ~PSGInstance();

	virtual void connect_port(unsigned long port, LADSPA_Data* dataLocation);
	virtual void activate();
	virtual void run(unsigned long SampleCount);

private:

	// ladspa ports:
	LADSPA_Data* port_freq;				//  0
	LADSPA_Data* port_amp;				//  1
	LADSPA_Data* port_noise;			//  2
	LADSPA_Data* port_audiotoggle;		//  3
	LADSPA_Data* port_noisetoggle;		//  4
	LADSPA_Data* port_env;				//  5
	LADSPA_Data* port_env_freq;			//  6
	LADSPA_Data* port_env_cont;			//  7
	LADSPA_Data* port_env_att;			//  8
	LADSPA_Data* port_env_alt;			//  9
	LADSPA_Data* port_env_hold;			// 10
	LADSPA_Data* port_output;			// 11
	LADSPA_Data* port_gate;				// 12

	// constants
	static const int FP_UNIT = 0x8000; // fixed point representation of 1
	static const int CLOCK_FREQ = 3579545/2; // real time clock frequency of AY8910

	const unsigned long sampleRate;

	// vars
	unsigned int updateStep;
	int period, periodN, periodE;
	int count, countN, countE;
	unsigned int vol, volE;
	bool envelope;
	unsigned char output, outputN;
	signed char countEnv;
	unsigned char attack;
	bool hold, alternate, holding;
	int random;
	unsigned int volTable[16];
	unsigned char oldEnable;
	int validLength;
	int reg_env_shape_backup;
	LADSPA_Data port_gate_backup;
	LADSPA_Data port_amp_backup;
	int reg_freq_backup;

	// methods
	void reset();
	void setInternalVolume(short newVolume);

};

#endif // __PSGINSTANCE_HH__
